@@ -109,3 +109,6 @@ class KeyPoints(BaseGeometry):
                                  fill=(*point_color, 255))
         del draw_obj
         return image
+
+    def __repr__(self):
+        return str(self.value)
